InserterBase class abstract

Core inserter interface for implementing specialized line readers.

Implementers

Constructors

InserterBase({required LineConverter readLines, required Iterable<File> files, required Iterable<MatcherBuilder> builders, Encoding encoding = utf8, StringBuffer? buffer})
Core inserter interface for implementing specialized line readers.

Properties

buffer StringBuffer
Buffer used for write files contents.
final
builders Iterable<MatcherBuilder>
When a match is made, the appropriate LineBuilder is executed.
final
encoding Encoding
Encoding used for writing files.
final
files Iterable<File>
Files that need to be registered for insertion for a giver Inserter.
final
hashCode int
The hash code for this object.
no setterinherited
readLines LineConverter
How the given file's contents are read.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute() Future<void>
Run all the builders on the given files.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited