builder property
Callback for writing generating a line(s) of code with the given context of the pattern and full line that was matched.
Implementation
final LineBuilder builder;
Callback for writing generating a line(s) of code with the given context of the pattern and full line that was matched.
final LineBuilder builder;