Inserter class
Tooling for inserting String into Files given
their respective strategies.
- Inheritance
-
- Object
- InserterBase
- Inserter
Constructors
-
Inserter({required Iterable<
MatcherBuilder> builders, required Iterable<File> files, StringBuffer? buffer, Encoding encoding = utf8}) -
Tooling for inserting
StringintoFiles given their respective strategies.
Properties
- buffer → StringBuffer
-
Buffer used for write files contents.
finalinherited
-
builders
→ Iterable<
MatcherBuilder> -
When a match is made, the appropriate LineBuilder is executed.
finalinherited
- encoding → Encoding
-
Encoding used for writing files.
finalinherited
-
files
→ Iterable<
File> -
Files that need to be registered for insertion for a giver Inserter.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- readLines → LineConverter
-
How the given file's contents are read.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → Future< void> -
Run all the builders on the given files.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
run(
{required Iterable< File> files, required Iterable<MatcherBuilder> builders, Encoding encoding = utf8, StringBuffer? buffer}) → Future<void> -
Convenience method for running an Inserter.execute
Run all the
builderson the givenfiles.