MatcherBuilder class
Describes the context of when a line is matched and how to build the line need for the Inserter calling it.
Constructors
- MatcherBuilder({required Matcher matcher, required LineBuilder builder, BuilderStrategy strategy = BuilderStrategy.below, StopWhen? stopWhen})
-
Describes the context of when a line is matched and how to build the
line need for the Inserter calling it.
const
Properties
- builder → LineBuilder
-
Callback for writing generating a line(s) of code with the given
context of the pattern and full line that was matched.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matcher → Matcher
-
Callback used when evaluating whether a line is matched
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopWhen → StopWhen?
-
Evaluated after MatcherBuilder.matcher and MatcherBuilder.builder
are executed.
final
- strategy → BuilderStrategy
-
Strategy used by a MatcherBuilder to determine where the results of
a LineBuilder should go.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited